"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * @license
 * Copyright 2020 Google LLC. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * =============================================================================
 */
// We explicitly import the modular kernels so they get registered in the
// global registry when we compile the library. A modular build would replace
// the contents of this file and import only the kernels that are needed.
var tfjs_core_1 = require("@tensorflow/tfjs-core");
var Add_1 = require("./kernels/Add");
var AddN_1 = require("./kernels/AddN");
var ArgMax_1 = require("./kernels/ArgMax");
var ArgMin_1 = require("./kernels/ArgMin");
var Diag_1 = require("./kernels/Diag");
var Dilation2D_1 = require("./kernels/Dilation2D");
var Dilation2DBackpropFilter_1 = require("./kernels/Dilation2DBackpropFilter");
var Dilation2DBackpropInput_1 = require("./kernels/Dilation2DBackpropInput");
var Equal_1 = require("./kernels/Equal");
var FloorDiv_1 = require("./kernels/FloorDiv");
var Greater_1 = require("./kernels/Greater");
var GreaterEqual_1 = require("./kernels/GreaterEqual");
var Less_1 = require("./kernels/Less");
var LessEqual_1 = require("./kernels/LessEqual");
var LogicalAnd_1 = require("./kernels/LogicalAnd");
var LogicalNot_1 = require("./kernels/LogicalNot");
var LogicalOr_1 = require("./kernels/LogicalOr");
var Max_1 = require("./kernels/Max");
var Maximum_1 = require("./kernels/Maximum");
var Min_1 = require("./kernels/Min");
var Minimum_1 = require("./kernels/Minimum");
var MirrorPad_1 = require("./kernels/MirrorPad");
var Multiply_1 = require("./kernels/Multiply");
var NonMaxSuppressionV4_1 = require("./kernels/NonMaxSuppressionV4");
var NonMaxSuppressionV5_1 = require("./kernels/NonMaxSuppressionV5");
var NotEqual_1 = require("./kernels/NotEqual");
var Prod_1 = require("./kernels/Prod");
var Softmax_1 = require("./kernels/Softmax");
var SquaredDifference_1 = require("./kernels/SquaredDifference");
var Sum_1 = require("./kernels/Sum");
var UnsortedSegmentSum_1 = require("./kernels/UnsortedSegmentSum");
// List all kernel configs here
var kernelConfigs = [
    Add_1.addConfig,
    AddN_1.addNConfig,
    ArgMax_1.argMaxConfig,
    ArgMin_1.argMinConfig,
    Diag_1.diagConfig,
    Dilation2DBackpropFilter_1.dilation2dBackpropFilterConfig,
    Dilation2DBackpropInput_1.dilation2dBackpropInputConfig,
    Dilation2D_1.dilation2dConfig,
    Equal_1.equalConfig,
    FloorDiv_1.floorDivConfig,
    Greater_1.greaterConfig,
    GreaterEqual_1.greaterEqualConfig,
    Less_1.lessConfig,
    LessEqual_1.lessEqualConfig,
    LogicalAnd_1.logicalAndConfig,
    LogicalNot_1.logicalNotConfig,
    LogicalOr_1.logicalOrConfig,
    Max_1.maxConfig,
    Maximum_1.maximumConfig,
    Min_1.minConfig,
    Minimum_1.minimumConfig,
    MirrorPad_1.mirrorPadConfig,
    Multiply_1.multiplyConfig,
    NonMaxSuppressionV4_1.nonMaxSuppressionV4Config,
    NonMaxSuppressionV5_1.nonMaxSuppressionV5Config,
    NotEqual_1.notEqualConfig,
    Prod_1.prodConfig,
    Softmax_1.softmaxConfig,
    SquaredDifference_1.squaredDifferenceConfig,
    Sum_1.sumConfig,
    UnsortedSegmentSum_1.unsortedSegmentSumConfig
];
for (var _i = 0, kernelConfigs_1 = kernelConfigs; _i < kernelConfigs_1.length; _i++) {
    var kernelConfig = kernelConfigs_1[_i];
    tfjs_core_1.registerKernel(kernelConfig);
}
